@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -66,6 +63,10 @@
 #define kUniNArbCtrlQAckDelay      (0x30)
 #define kUniNArbCtrlQAckDelay105   (0x00)
 
+#define kUniNAACKCtrl                  (0x0100)
+#define kUniNAACKCtrlDelayEnableMask   (0x00000001)
+#define kUniNAACKCtrlDelayEnable       (0x00000001)
+
 #define kUniNHWInitState           (0x0070)
 #define kUniNHWInitStateSleeping   (0x01)
 #define kUniNHWInitStateRunning    (0x02)
@@ -137,6 +138,7 @@
 #define kAAPLSuspendablePorts	"AAPL,SuspendablePorts"
 
 #define kUniNSetPowerState		"UniNSetPowerState"
+#define kUniNSetAACKDelay		"UniNSetAACKDelay"
 
 class AppleUniN: public ApplePlatformExpert
 {
@@ -167,6 +169,7 @@ private:
 	OSArray 				*platformFuncArray;
     IOMemoryMap				*uATABaseAddressMap;
 	volatile UInt32			*uATABaseAddress;
+    UInt32					uATAFCR;
 	bool					hostIsMobile;
 	const OSSymbol			*symReadIntrepidClockStopStatus;
 
@@ -176,6 +179,7 @@ private:
 	virtual void safeWriteRegUInt32(UInt32 offset, UInt32 mask, UInt32 data);
 	virtual void configureUniNPCIDevice (IOService *nub);
 	virtual void uniNSetPowerState (UInt32 state);
+	virtual void setAACKDelay (UInt32 setDelayBit);
 
 	virtual bool performFunction(const IOPlatformFunction *func, void *param1 = 0,
 			void *param2 = 0, void *param3 = 0, void *param4 = 0);
